"""
ExtractTiles: Basic Use Case
============================

met_tool_wrapper/ExtractTiles/ExtractTiles.conf

"""
##############################################################################
# Scientific Objective
# --------------------
#
# Read a storm stat file generated by TC-Stat and for each point on the track
# create an cutout of forecast and observation data valid at the track time
#

##############################################################################
# Datasets
# --------
#
# | **Track Data:** Output from TC-Stat generated from ADeck and Bdeck modified-ATCF tropical cyclone data
# | **Forecast:** GFS
# | **Observation:** GFS Analysis
#
# | **Location:** All of the input data required for this use case can be found in the met_test sample data tarball. Click here to the METplus releases page and download sample data for the appropriate release: https://github.com/dtcenter/METplus/releases
# | This tarball should be unpacked into the directory that you will set the value of INPUT_BASE. See `Running METplus`_ section for more information.
# |

##############################################################################
# METplus Components
# ------------------
#
# This use case utilizes the METplus ExtractTiles wrapper to search for
# files that are valid at a given run time and generate a command to run
# the MET tool regrid_data_plane if all required files are found.

##############################################################################
# METplus Workflow
# ----------------
#
# ExtractTiles is the only tool called in this example.
# It processes the following run time:
#
# | **Init:** 2014-12-14 0Z
# |
#

##############################################################################
# METplus Configuration
# ---------------------
#
# METplus first loads all of the configuration files found in parm/metplus_config,
# then it loads any configuration files passed to METplus via the command line
# with the -c option, i.e. -c parm/use_cases/met_tool_wrapper/ExtractTiles/ExtractTiles.conf
#
# .. highlight:: bash
# .. literalinclude:: ../../../../parm/use_cases/met_tool_wrapper/ExtractTiles/ExtractTiles.conf

##############################################################################
# MET Configuration
# ---------------------
#
# None. RegridDataPlane does not use configuration files.
#

##############################################################################
# Running METplus
# ---------------
#
# This use case can be run two ways:
#
# 1) Passing in ExtractTiles.conf then a user-specific system configuration file::
#
#        run_metplus.py -c /path/to/METplus/parm/use_cases/met_tool_wrapper/ExtractTiles/ExtractTiles.conf -c /path/to/user_system.conf
#
# 2) Modifying the configurations in parm/metplus_config, then passing in ExtractTiles.conf::
#
#        run_metplus.py -c /path/to/METplus/parm/use_cases/met_tool_wrapper/ExtractTiles/ExtractTiles.conf
#
# The former method is recommended. Whether you add them to a user-specific configuration file or modify the metplus_config files, the following variables must be set correctly:
#
# * **INPUT_BASE** - Path to directory where sample data tarballs are unpacked (See Datasets section to obtain tarballs). This is not required to run METplus, but it is required to run the examples in parm/use_cases
# * **OUTPUT_BASE** - Path where METplus output will be written. This must be in a location where you have write permissions
# * **MET_INSTALL_DIR** - Path to location where MET is installed locally
#
# Example User Configuration File::
#
#   [dir]
#   INPUT_BASE = /path/to/sample/input/data
#   OUTPUT_BASE = /path/to/output/dir
#   MET_INSTALL_DIR = /path/to/met-X.Y 
#
# **NOTE:** All of these items must be found under the [dir] section.
#

##############################################################################
# Expected Output
# ---------------
#
# A successful run will output the following both to the screen and to the logfile::
#
#   INFO: METplus has successfully finished running.
#
# Refer to the value set for **OUTPUT_BASE** to find where the output data was generated.
# Output for this use case will be found in met_tool_wrapper/ExtractTiles/20141214_00 (relative to **OUTPUT_BASE**)
# and will contain the following files:
#
# * ML1200942014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1200942014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1200942014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1200942014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1200942014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1200942014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1200942014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1200942014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1200942014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1200942014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1200942014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1200942014/FCST_TILE_F048_gfs_4_20141214_0000_048.nc
# * ML1200972014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1200972014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1200972014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1200972014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1200972014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1200972014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1200972014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1200972014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1200972014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1200972014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1200972014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1200972014/FCST_TILE_F048_gfs_4_20141214_0000_048.nc
# * ML1200992014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1200992014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1200992014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1200992014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1200992014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1200992014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1200992014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201002014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201002014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201002014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201002014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201002014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201002014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201002014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201002014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201002014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201002014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201032014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201032014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201032014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201032014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201032014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201032014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201032014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201032014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201032014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201032014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201032014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1201032014/FCST_TILE_F048_gfs_4_20141214_0000_048.nc
# * ML1201042014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201042014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201042014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201042014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201042014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201042014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201042014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201042014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201042014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201042014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201042014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1201052014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201052014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201052014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201052014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201052014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201052014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201052014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201052014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201062014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201062014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201062014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201062014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201062014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201062014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201062014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201062014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201062014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201062014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201072014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201072014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201072014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201072014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201072014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201072014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201072014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201072014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201072014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201072014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201072014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1201072014/FCST_TILE_F048_gfs_4_20141214_0000_048.nc
# * ML1201082014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201082014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201082014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201082014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201082014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201082014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201082014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201082014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201082014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201082014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201082014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1201082014/FCST_TILE_F048_gfs_4_20141214_0000_048.nc
# * ML1201092014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201092014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201092014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201092014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201092014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201092014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201092014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201092014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201092014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201092014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
# * ML1201092014/FCST_TILE_F042_gfs_4_20141214_0000_042.nc
# * ML1201102014/ANLY_TILE_F006_gfs_4_20141214_0600_000.nc
# * ML1201102014/ANLY_TILE_F012_gfs_4_20141214_1200_000.nc
# * ML1201102014/ANLY_TILE_F018_gfs_4_20141214_1800_000.nc
# * ML1201102014/ANLY_TILE_F036_gfs_4_20141215_1200_000.nc
# * ML1201102014/FCST_TILE_F006_gfs_4_20141214_0000_006.nc
# * ML1201102014/FCST_TILE_F012_gfs_4_20141214_0000_012.nc
# * ML1201102014/FCST_TILE_F018_gfs_4_20141214_0000_018.nc
# * ML1201102014/FCST_TILE_F024_gfs_4_20141214_0000_024.nc
# * ML1201102014/FCST_TILE_F030_gfs_4_20141214_0000_030.nc
# * ML1201102014/FCST_TILE_F036_gfs_4_20141214_0000_036.nc
#

##############################################################################
# Keywords
# --------
#
# .. note:: `RegridDataPlaneToolUseCase <https://dtcenter.github.io/METplus/develop/search.html?q=RegridDataPlaneToolUseCase&check_keywords=yes&area=default>`_, `GRIB2FileUseCase  <https://dtcenter.github.io/METplus/develop/search.html?q=GRIB2FileUseCase&check_keywords=yes&area=default>`_, `FeatureRelativeUseCase  <https://dtcenter.github.io/METplus/develop/search.html?q=FeatureRelativeUseCase&check_keywords=yes&area=default>`_
#
# sphinx_gallery_thumbnail_path = '_static/met_tool_wrapper-ExtractTiles.png'
